==> jc-1.4.0.tar.gz: jas/CatchEntry.h <==
// public class jas.CatchEntry

// class file dependencies
// @dep_class a93aee87b6345067 jas_CatchEntry
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_CatchEntry_H_
#define _JC_jas_CatchEntry_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_jas_Label$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_CatchEntry$sub_refs	_jc_jas_CatchEntry$sub_refs;
typedef struct _jc_jas_CatchEntry$sub_nonrefs	_jc_jas_CatchEntry$sub_nonrefs;
typedef struct _jc_jas_CatchEntry$refs	_jc_jas_CatchEntry$refs;
typedef struct _jc_jas_CatchEntry$nonrefs	_jc_jas_CatchEntry$nonrefs;
typedef struct _jc_jas_CatchEntry$object	_jc_jas_CatchEntry$object;

typedef const struct _jc_jas_CatchEntry$vmethods	_jc_jas_CatchEntry$vmethods;
typedef const struct _jc_jas_CatchEntry$vtable	_jc_jas_CatchEntry$vtable;
typedef const struct _jc_jas_CatchEntry$vtype	_jc_jas_CatchEntry$vtype;

// Constructors
extern void _jc_jas_CatchEntry$method$_init$81d442b5211b5283(_jc_env *, struct _jc_jas_CatchEntry$object *, struct _jc_jas_Label$object *, struct _jc_jas_Label$object *, struct _jc_jas_Label$object *, struct _jc_jas_CP$object *);

// Virtual methods
extern void _jc_jas_CatchEntry$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_CatchEntry$object *, struct _jc_jas_ClassEnv$object *);
extern void _jc_jas_CatchEntry$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_CatchEntry$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_CatchEntry$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_CatchEntry$method_info$write$d61e8c36d8c1cacd;

// Virtual methods structure
struct _jc_jas_CatchEntry$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_CatchEntry$object *, struct _jc_jas_ClassEnv$object *);
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_CatchEntry$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_CatchEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CatchEntry$vmethods	jas_CatchEntry;
};

// Vtype
struct _jc_jas_CatchEntry$vtype {
	_jc_type			type;
	_jc_jas_CatchEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_CatchEntry$sub_refs {
	struct _jc_jas_Label$object	*start__5fpc;
	struct _jc_jas_Label$object	*end__5fpc;
	struct _jc_jas_Label$object	*handler__5fpc;
	struct _jc_jas_CP$object	*catch__5fcpe;
};

// Reference instance fields (object)
struct _jc_jas_CatchEntry$refs {
    _jc_jas_CatchEntry$sub_refs	jas_CatchEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_CatchEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_CatchEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CatchEntry$sub_nonrefs	jas_CatchEntry;
};

// Object instance structure
struct _jc_jas_CatchEntry$object {
	_jc_jas_CatchEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_CatchEntry$vtype	*vtype;
	_jc_jas_CatchEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_CatchEntry$vtype _jc_jas_CatchEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_CatchEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_CatchEntry$class_object;

#endif	/* _JC_jas_CatchEntry_H_ */

==> jc-1.4.6.tar.gz: jas/CatchEntry.h <==
// public class jas.CatchEntry

// class file dependencies
// @dep_class a93aee87b6345067 jas_CatchEntry
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_CatchEntry_H_
#define _JC_jas_CatchEntry_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_jas_Label$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_CatchEntry$sub_refs	_jc_jas_CatchEntry$sub_refs;
typedef struct _jc_jas_CatchEntry$sub_nonrefs	_jc_jas_CatchEntry$sub_nonrefs;
typedef struct _jc_jas_CatchEntry$refs	_jc_jas_CatchEntry$refs;
typedef struct _jc_jas_CatchEntry$nonrefs	_jc_jas_CatchEntry$nonrefs;
typedef struct _jc_jas_CatchEntry$object	_jc_jas_CatchEntry$object;

typedef const struct _jc_jas_CatchEntry$vmethods	_jc_jas_CatchEntry$vmethods;
typedef const struct _jc_jas_CatchEntry$vtable	_jc_jas_CatchEntry$vtable;
typedef const struct _jc_jas_CatchEntry$vtype	_jc_jas_CatchEntry$vtype;

// Constructors
extern void _jc_jas_CatchEntry$method$_init$81d442b5211b5283(_jc_env *, struct _jc_jas_CatchEntry$object *, struct _jc_jas_Label$object *, struct _jc_jas_Label$object *, struct _jc_jas_Label$object *, struct _jc_jas_CP$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_CatchEntry$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_CatchEntry$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern void _jc_jas_CatchEntry$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_CatchEntry$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_CatchEntry$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_CatchEntry$method_info$write$d61e8c36d8c1cacd;

// Virtual methods structure
struct _jc_jas_CatchEntry$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_CatchEntry$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_CatchEntry$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_CatchEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CatchEntry$vmethods	jas_CatchEntry;
};

// Vtype
struct _jc_jas_CatchEntry$vtype {
	_jc_type			type;
	_jc_jas_CatchEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_CatchEntry$sub_refs {
	struct _jc_jas_Label$object	*start__5fpc;
	struct _jc_jas_Label$object	*end__5fpc;
	struct _jc_jas_Label$object	*handler__5fpc;
	struct _jc_jas_CP$object	*catch__5fcpe;
};

// Reference instance fields (object)
struct _jc_jas_CatchEntry$refs {
    _jc_jas_CatchEntry$sub_refs	jas_CatchEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_CatchEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_CatchEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CatchEntry$sub_nonrefs	jas_CatchEntry;
};

// Object instance structure
struct _jc_jas_CatchEntry$object {
	_jc_jas_CatchEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_CatchEntry$vtype	*vtype;
	_jc_jas_CatchEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_CatchEntry$vtype _jc_jas_CatchEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_CatchEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_CatchEntry$class_object;

#endif	/* _JC_jas_CatchEntry_H_ */
